History
=======

0.5 - 2016-02-22
----------------

- Added gevent pool and concurrency option
- Fixed multiple SSL errors
- Added alternative URL option when ignoring log

0.4 - 2016-02-21
----------------

- Fixed changelog lLink

0.3 - 2016-02-20
----------------

- Improved help display


0.2 - 2016-02-20
----------------

- Initial release

No notes on earlier releases.
